@@ -1,6 +1,6 @@
 from .interval import Interval, I
 from .dists import *
-from .pbox import Pbox
+from .pbox import *
 from .logic import *
 # from .copula import __all__
 from .core import *
\ No newline at end of file
