@@ -31,18 +31,18 @@ class Logical:
 
     __str__ = __repr__
 
-def always(Logical):
-    assert isinstance(Logical, Logical)
+def always(logical):
+    assert logical.__class__.__name__ == 'Logical'
 
-    if Logical.Left == Logical.Right == 1:
+    if logical.Left == logical.Right == 1:
         return True
     else:
         return False
 
-def sometimes(Logical):
-    assert isinstance(Logical, Logical)
+def sometimes(logical):
+    assert logical.__class__.__name__ == 'Logical'
 
-    if Logical:
+    if logical:
         # using Logical.__bool__
         return True
     else:
